.. -*- encoding: utf-8; mode: rst -*-
    >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>><<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
    >>>>>>>>>>>>>>>> IMPORTANT: READ THIS BEFORE EDITING! <<<<<<<<<<<<<<<<
    >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>><<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
    Please keep each sentence on its own unwrapped line.
    It looks like crap in a text editor, but it has no effect on rendering, and it allows much more useful diffs.
    Thank you!

Copyright |(c)| 2015 `Matt Bogosian`_ (|@posita|_).

.. |(c)| unicode:: u+a9
.. _`Matt Bogosian`: mailto:mtb19@columbia.edu?Subject=txrc
.. |@posita| replace:: **@posita**
.. _`@posita`: https://github.com/posita

Please see the accompanying |LICENSE|_ (or |LICENSE.txt|_) file for rights and restrictions governing use of this software.
All rights not expressly waived or licensed are reserved.
If such a file did not accompany this software, then please contact the author before viewing or using this software in any capacity.

.. |LICENSE| replace:: ``LICENSE``
.. _`LICENSE`: LICENSE
.. |LICENSE.txt| replace:: ``LICENSE.txt``
.. _`LICENSE.txt`: LICENSE

.. image:: https://travis-ci.org/posita/txrc.svg?branch=v0.1.0
    :target: https://travis-ci.org/posita/txrc?branch=v0.1.0
    :alt: [Build Status]

.. image:: https://coveralls.io/repos/posita/txrc/badge.svg?branch=v0.1.0
    :target: https://coveralls.io/r/posita/txrc?branch=v0.1.0
    :alt: [Coverage Status]

Curious about integrating your project with the above services?
Jeff Knupp (|@jeffknupp|_) `describes how <https://www.jeffknupp.com/blog/2013/08/16/open-sourcing-a-python-project-the-right-way/>`__.

.. |@jeffknupp| replace:: **@jeffknupp**
.. _`@jeffknupp`: https://github.com/jeffknupp

``txrc`` - Twisted Retrying Caller Inspired by Terry Jones
==========================================================

.. image:: https://pypip.in/version/txrc/badge.svg
    :target: https://pypi.python.org/pypi/txrc/
    :alt: [Latest Version]

.. image:: https://readthedocs.org/projects/txrc/badge/?version=v0.1.0
    :target: https://txrc.readthedocs.org/en/v0.1.0/
    :alt: [Documentation]

.. image:: https://pypip.in/license/txrc/badge.svg
    :target: https://opensource.org/licenses/MIT
    :alt: [License]

.. image:: https://pypip.in/py_versions/txrc/badge.svg
    :target: https://pypi.python.org/pypi/txrc/0.1.0
    :alt: [Supported Python Versions]

.. image:: https://pypip.in/implementation/txrc/badge.svg
    :target: https://pypi.python.org/pypi/txrc/0.1.0
    :alt: [Supported Python Implementations]

.. image:: https://pypip.in/status/txrc/badge.svg
    :target: https://pypi.python.org/pypi/txrc/0.1.0
    :alt: [Development Stage]

..

``txrc`` enables retrying calls in `Twisted <https://twistedmatrix.com/>`_.
It is based on `Terry Jones's proposal <http://blogs.fluidinfo.com/terry/2009/11/12/twisted-code-for-retrying-function-calls/>`__.
It is licensed under the `MIT License <https://opensource.org/licenses/MIT>`_.
Source code is `available on GitHub <https://github.com/posita/txrc>`__.
See `the docs <https://txrc.readthedocs.org/en/master/>`__ for more information.

Issues
------

If you find a bug, or want a feature, please `file an issue <https://github.com/posita/txrc/issues>`__ (if it hasn't already been filed).
If you're willing and able, consider `contributing <https://txrc.readthedocs.org/en/master/contrib.html>`__.
